@@ -154,6 +154,9 @@ function handleDeleteRequest($userMgmt, $action, $authData) {
 }
 
 function createUser($userMgmt, $input, $authData) {
+    // Log the complete input from WHMCS for debugging
+    error_log("WHMCS User Creation Request: " . json_encode($input));
+    
     $required = ['username', 'password'];
     foreach ($required as $field) {
         if (empty($input[$field])) {
@@ -163,9 +166,12 @@ function createUser($userMgmt, $input, $authData) {
     
     // Optional resource limits
     $resources = $input['resources'] ?? [];
+    error_log("Resources from WHMCS for {$input['username']}: " . json_encode($resources));
     
     // Skip default resources if custom resources are provided
     $skip_defaults = !empty($resources);
+    error_log("Skip defaults for {$input['username']}: " . ($skip_defaults ? 'true' : 'false'));
+    
     $result = $userMgmt->create_new_user($input['username'], $input['password'], $skip_defaults);
     
     if ($result['status'] === '0') {
@@ -349,34 +355,37 @@ function setUserResources($username, $resources) {
         $db = $MySQLMgmt->getMySQLConnection();
         $db->exec("USE whp");
         
+        // Extract resource values with detailed logging
+        $cpu_cores = $resources['cpu_cores'] ?? 0.5;
+        $memory_mb = $resources['memory_mb'] ?? 512;
+        $disk_mb = $resources['disk_mb'] ?? 1000;
+        $email_accounts = $resources['email_accounts'] ?? 0;
+        $email_storage_mb = $resources['email_storage_mb'] ?? 1000;
+        
+        error_log("Calling updateClientAllowances for {$username} with: CPU={$cpu_cores}, Memory={$memory_mb}, Disk={$disk_mb}, Email={$email_accounts}, EmailStorage={$email_storage_mb}");
+        
         // Use the proper updateClientAllowances method for validation and quota sync
+        // This method already handles filesystem quota syncing internally
         $result = $MySQLMgmt->updateClientAllowances(
             $username,
-            $resources['cpu_cores'] ?? 0.5,
-            $resources['memory_mb'] ?? 512,
+            $cpu_cores,
+            $memory_mb,
             null, // max_domains not needed for this call
-            $resources['disk_mb'] ?? 1000,
-            $resources['email_accounts'] ?? 0,
-            $resources['email_storage_mb'] ?? 1000
+            $disk_mb,
+            $email_accounts,
+            $email_storage_mb
         );
         
-        // Sync filesystem quota if disk space was provided
-        if (isset($resources['disk_mb']) && $result['status'] === '0') {
-            $disk_quota_mb = intval($resources['disk_mb']);
-            $quota_cmd = '/root/whp/scripts/quota-helper.sh set ' . escapeshellarg($username) . ' ' . $disk_quota_mb . ' 2>&1';
-            $quota_output = shell_exec($quota_cmd);
-            $quota_exit_code = 0;
-            exec('/root/whp/scripts/quota-helper.sh set ' . escapeshellarg($username) . ' ' . $disk_quota_mb, $quota_exec_output, $quota_exit_code);
-            
-            if ($quota_exit_code !== 0) {
-                error_log("Failed to update filesystem quota for {$username} to {$disk_quota_mb}MB (exit code: $quota_exit_code): " . trim($quota_output));
-            }
+        if ($result['status'] === '0') {
+            error_log("Successfully set resources for {$username}: CPU={$resources['cpu_cores']}, Memory={$resources['memory_mb']}, Disk={$resources['disk_mb']}, Email={$resources['email_accounts']}, EmailStorage={$resources['email_storage_mb']}");
+        } else {
+            error_log("Failed to set resources for {$username}: " . $result['msg']);
         }
         
         return $result['status'] === '0';
         
     } catch (Exception $e) {
-        error_log("Error setting user resources: " . $e->getMessage());
+        error_log("Error setting user resources for {$username}: " . $e->getMessage());
         return false;
     }
 }
